import { AudioAssetConfig, VideoAssetConfig, ImageAssetConfig, TextAssetConfig, TextStyleProps } from '../types/config';
/**
 * The base MediaAsset class
 */
declare class MediaAsset {
    assetId: string;
    constructor(assetId: string);
}
/**
 * VideoAsset class
 */
export declare class VideoAsset extends MediaAsset {
    start: number;
    end: number | null;
    /**
     * Initializes a AudioAsset instance
     * @param assetId - The id of the audio asset.
     * @param config - The configuration of the audio asset.
     * @returns A new AudioAsset instance.
     */
    constructor(assetId: string, config?: Partial<VideoAssetConfig>);
    toJSON(): {
        assetId: string;
        start: number;
        end: number | null;
    };
}
/**
 * AudioAsset class
 */
export declare class AudioAsset extends MediaAsset {
    start: number;
    end: number | null;
    disableOtherTracks: boolean;
    fadeInDuration: number;
    fadeOutDuration: number;
    /**
     * Initializes a AudioAsset instance
     * @param assetId - The id of the audio asset.
     * @param config - The configuration of the audio asset.
     * @returns A new AudioAsset instance.
     */
    constructor(assetId: string, config?: Partial<AudioAssetConfig>);
    toJSON(): {
        assetId: string;
        start: number;
        disableOtherTracks: boolean;
        fadeInDuration: number;
        fadeOutDuration: number;
        end: number | null;
    };
}
export declare class ImageAsset extends MediaAsset {
    width: number | string;
    height: number | string;
    x: number | string;
    y: number | string;
    duration: number | null;
    constructor(assetId: string, config?: Partial<ImageAssetConfig>);
    toJSON(): {
        assetId: string;
        width: string | number;
        height: string | number;
        x: string | number;
        y: string | number;
        duration: number | null;
    };
}
export declare class TextAsset extends MediaAsset {
    text: string;
    duration: number | null;
    style: Partial<TextStyleProps>;
    constructor(config?: Partial<TextAssetConfig>);
    toJSON(): {
        assetId: string;
        text: string;
        style: {
            fontsize?: number | undefined;
            fontcolor?: string | undefined;
            fontcolorExpr?: string | undefined;
            alpha?: number | undefined;
            font?: string | undefined;
            box?: boolean | undefined;
            boxcolor?: string | undefined;
            boxborderw?: string | undefined;
            boxw?: number | undefined;
            boxh?: number | undefined;
            lineSpacing?: number | undefined;
            textAlign?: string | undefined;
            yAlign?: string | undefined;
            borderw?: number | undefined;
            bordercolor?: string | undefined;
            expansion?: string | undefined;
            basetime?: number | undefined;
            fixBounds?: boolean | undefined;
            textShaping?: boolean | undefined;
            shadowcolor?: string | undefined;
            shadowx?: number | undefined;
            shadowy?: number | undefined;
            tabsize?: number | undefined;
            x?: string | number | undefined;
            y?: string | number | undefined;
        };
        duration: number | null;
    };
}
export {};
