import { Collection } from '../core/collection';
import type { FileUploadConfig, URLUploadConfig } from '../types/collection';
import { HttpClient } from '../utils/httpClient';
/**
 * Initalizon precedes connection
 * establishment. Is used to get the
 * primary collection.
 */
export declare class Connection {
    vhttp: HttpClient;
    constructor(baseURL: string, ApiKey: string);
    /**
     * Get an instance of the Collection class
     * @param id - [Optional] ID of the collection
     * @returns
     * If ID is provided, returns the corresponding collection,
     * else returns the default collection.
     */
    getCollection(id?: string): Promise<Collection>;
    /**
     * Get all Collections from db
     * @returns
     * Returns an array of Collection objects
     */
    getCollections(): Promise<Collection[]>;
    /**
     * Create a new collection
     * @param name - Name of the collection
     * @param description - Description of the collection
     * @returns
     * Returns a new Collection object
     */
    createCollection: (name: string, description: string) => Promise<Collection>;
    /**
     * Update a collection
     * @param id - ID of the collection
     * @param name - Name of the collection
     * @param desscription - Description of the collection
     * @returns
     * Returns an updated Collection object
     */
    updateCollection(id: string, name: string, description: string): Promise<Collection>;
    /**
     * @param filePath - absolute path to a file
     * @param callbackUrl- [optional] A url that will be called once upload is finished
     * @param name - [optional] Name of the file
     * @param description - [optional] Description of the file
     *
     * @see
     * Providing a callbackUrl will return undefined and not providing one
     * will return a Job object (TODO: Implement proper type for this condition)
     */
    uploadFile: (collectionId: string | undefined, data: FileUploadConfig) => Promise<import("..").UploadJob | undefined>;
    /**
     * @param URL - URL of the hosted file
     * @param callbackUrl- [optional] A url that will be called once upload is finished
     * @param name - [optional] Name of the file
     * @param description - [optional] Description of the file
     *
     * @see
     * Providing a callbackUrl will return undefined and not providing one
     * will return a Job object (TODO: Implement proper type for this condition)
     */
    uploadURL: (collectionId: string | undefined, data: URLUploadConfig) => Promise<import("..").UploadJob | undefined>;
}
