"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Connection = void 0;
const constants_1 = require("../constants");
const collection_1 = require("../core/collection");
const utils_1 = require("../utils");
const httpClient_1 = require("../utils/httpClient");
const upload_1 = require("../utils/upload");
const { collection } = constants_1.ApiPath;
class VdbHttpClient extends httpClient_1.HttpClient {
    constructor(baseURL, apiKey) {
        super(baseURL, apiKey);
    }
}
/**
 * Initalizon precedes connection
 * establishment. Is used to get the
 * primary collection.
 */
class Connection {
    vhttp;
    constructor(baseURL, ApiKey) {
        this.vhttp = new VdbHttpClient(baseURL, ApiKey);
    }
    /**
     * Get an instance of the Collection class
     * @param id - [Optional] ID of the collection
     * @returns
     * If ID is provided, returns the corresponding collection,
     * else returns the default collection.
     */
    async getCollection(id = 'default') {
        const res = await this.vhttp.get([collection, id]);
        const convertedData = (0, utils_1.fromSnakeToCamel)(res.data);
        const _collection = new collection_1.Collection(this.vhttp, convertedData);
        return _collection;
    }
    /**
     * Get all Collections from db
     * @returns
     * Returns an array of Collection objects
     */
    async getCollections() {
        const res = await this.vhttp.get([collection]);
        const collectionsResponse = (0, utils_1.fromSnakeToCamel)(res.data);
        const collections = collectionsResponse.collections.map(_collection => {
            const convertedData = (0, utils_1.fromSnakeToCamel)(_collection);
            return new collection_1.Collection(this.vhttp, convertedData);
        });
        return collections;
    }
    /**
     * Create a new collection
     * @param name - Name of the collection
     * @param description - Description of the collection
     * @returns
     * Returns a new Collection object
     */
    createCollection = async (name, description) => {
        const res = await this.vhttp.post([collection], {
            name,
            description,
        });
        const convertedData = (0, utils_1.fromSnakeToCamel)(res.data);
        return new collection_1.Collection(this.vhttp, convertedData);
    };
    /**
     * Update a collection
     * @param id - ID of the collection
     * @param name - Name of the collection
     * @param desscription - Description of the collection
     * @returns
     * Returns an updated Collection object
     */
    async updateCollection(id, name, description) {
        const res = await this.vhttp.patch([collection, id], {
            name,
            description,
        });
        const convertedData = (0, utils_1.fromSnakeToCamel)(res.data);
        return new collection_1.Collection(this.vhttp, convertedData);
    }
    /**
     * @param filePath - absolute path to a file
     * @param callbackUrl- [optional] A url that will be called once upload is finished
     * @param name - [optional] Name of the file
     * @param description - [optional] Description of the file
     *
     * @see
     * Providing a callbackUrl will return undefined and not providing one
     * will return a Job object (TODO: Implement proper type for this condition)
     */
    uploadFile = async (collectionId = 'default', data) => {
        return (0, upload_1.uploadToServer)(this.vhttp, collectionId, data);
    };
    /**
     * @param URL - URL of the hosted file
     * @param callbackUrl- [optional] A url that will be called once upload is finished
     * @param name - [optional] Name of the file
     * @param description - [optional] Description of the file
     *
     * @see
     * Providing a callbackUrl will return undefined and not providing one
     * will return a Job object (TODO: Implement proper type for this condition)
     */
    uploadURL = async (collectionId = 'default', data) => {
        return (0, upload_1.uploadToServer)(this.vhttp, collectionId, data);
    };
}
exports.Connection = Connection;
