"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchFactory = void 0;
const constants_1 = require("../../constants");
const config_1 = require("../../core/config");
const searchResult_1 = require("./searchResult");
const { video, search, collection } = constants_1.ApiPath;
// class SceneSearch implements Search<SceneVideoSearch, SceneCollectionSearch> {
//   #vhttp: HttpClient;
//   constructor(http: HttpClient) {
//     this.#vhttp = http;
//   }
//   private getRequestData = (data: SceneVideoSearch | SceneCollectionSearch) => {
//     return {
//       index_type: data.indexType ?? DefaultIndexType,
//       search_type: data.searchType ?? DefaultSearchType,
//       query: data.query,
//       score_threshold:
//         data.scoreThreshold ?? SemanticSearchDefaultValues.scoreThreshold,
//       result_threshold:
//         data.resultThreshold ?? SemanticSearchDefaultValues.resultThreshold,
//     };
//   };
//   searchInsideVideo = async (data: SemanticVideoSearch) => {
//     const reqData = this.getRequestData(data);
//     const res = await this.#vhttp.post<SearchResponse, typeof reqData>(
//       [video, data.videoId, search],
//       reqData
//     );
//     return new SearchResult(this.#vhttp, res.data);
//   };
//   searchInsideCollection = async (data: SceneCollectionSearch) => {
//     throw new Error(
//       'Method not implemented. Scene search is not supported for Collection'
//     );
//   };
// }
class SemanticSearch {
    #vhttp;
    constructor(http) {
        this.#vhttp = http;
    }
    getRequestData = (data) => {
        return {
            index_type: config_1.SearchTypeValues.semantic,
            query: data.query,
            score_threshold: data.scoreThreshold ?? constants_1.SemanticSearchDefaultValues.scoreThreshold,
            result_threshold: data.resultThreshold ?? constants_1.SemanticSearchDefaultValues.resultThreshold,
        };
    };
    searchInsideVideo = async (data) => {
        const reqData = this.getRequestData(data);
        const res = await this.#vhttp.post([video, data.videoId, search], reqData);
        return new searchResult_1.SearchResult(this.#vhttp, res.data);
    };
    searchInsideCollection = async (data) => {
        const reqData = this.getRequestData(data);
        const res = await this.#vhttp.post([collection, data.collectionId, search], reqData);
        return new searchResult_1.SearchResult(this.#vhttp, res.data);
    };
}
class KeywordSearch {
    #vhttp;
    constructor(http) {
        this.#vhttp = http;
    }
    getRequestData = (data) => {
        return {
            index_type: config_1.SearchTypeValues.keyword,
            query: data.query,
            score_threshold: data.scoreThreshold ?? constants_1.KeywordSearchDefaultValues.scoreThreshold,
            result_threshold: data.resultThreshold ?? constants_1.KeywordSearchDefaultValues.resultThreshold,
        };
    };
    searchInsideVideo = async (data) => {
        const reqData = this.getRequestData(data);
        const res = await this.#vhttp.post([video, data.videoId, search], reqData);
        return new searchResult_1.SearchResult(this.#vhttp, res.data);
    };
    searchInsideCollection = async (data) => {
        throw new Error('Method not implemented. Keyword search is not supported for Collection');
    };
}
const searchType = {
    semantic: SemanticSearch,
    keyword: KeywordSearch,
};
class SearchFactory {
    vhttp;
    constructor(http) {
        this.vhttp = http;
    }
    getSearch(type) {
        return new searchType[type](this.vhttp);
    }
}
exports.SearchFactory = SearchFactory;
