"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchResult = void 0;
const shot_1 = require("../../core/shot");
const utils_1 = require("../../utils");
const error_1 = require("../../utils/error");
class SearchResult {
    #vhttp;
    #searchResponse;
    shots;
    streamUrl;
    playerUrl;
    collectionId = 'default';
    constructor(http, searchResponse) {
        this.#vhttp = http;
        this.#searchResponse = searchResponse;
        this.shots = [];
        this.#formatResults();
    }
    #formatResults = () => {
        for (const result of this.#searchResponse.results) {
            if (result.collection_id)
                this.collectionId = result.collection_id;
            for (const doc of result.docs) {
                this.shots.push(new shot_1.Shot(this.#vhttp, {
                    end: doc.end,
                    start: doc.start,
                    text: doc.text,
                    searchScore: doc.score,
                    videoId: result.video_id,
                    videoTitle: result.title,
                    videoLength: parseFloat(result.length),
                }));
            }
        }
    };
    compile = async () => {
        if (this.streamUrl)
            return this.streamUrl;
        else if (this.shots.length) {
            const reqData = this.shots.map(shot => {
                return {
                    video_id: shot.meta.videoId,
                    collection_id: this.collectionId,
                    shots: [[shot.meta.start, shot.meta.end]],
                };
            });
            const res = await this.#vhttp.post(['compile'], reqData);
            this.streamUrl = res.data.stream_url;
            this.playerUrl = res.data.player_url;
            return this.streamUrl;
        }
        else {
            throw new error_1.VideodbError('No shots found in the search result to compile');
        }
    };
    play = async () => {
        if (!this.streamUrl) {
            this.streamUrl = await this.compile();
        }
        return (0, utils_1.playStream)(this.streamUrl);
    };
}
exports.SearchResult = SearchResult;
