import { AudioAsset, VideoAsset, ImageAsset, TextAsset } from './asset';
import { Connection } from './connection';
import { ITimeline } from '../interfaces/core';
export declare class Timeline implements ITimeline {
    #private;
    timeline: Array<object>;
    streamUrl: string;
    playerUrl: string;
    /**
     * Initialize a timeline object
     * @param connection - Connection object. See [[Connection]]
     * @returns Timeline object
     */
    constructor(connection: Connection);
    private getRequestData;
    /**
     * Adds a VideoAsset to the timeline in inline position
     * @param asset - VideoAsset object. Can be created using [[VideoAsset]]
     */
    addInline(asset: VideoAsset): void;
    /**
     * Adds a AudioAsset to the timeline in overlay position
     * @param start - Start time of the overlay w.r.t Base Timline
     * @param asset - AudioAsset, ImageAsset or TextAsset object.
     */
    addOverlay(start: number, asset: AudioAsset | ImageAsset | TextAsset): void;
    /**
     * Generates a Streaming URL for the Timeline object
     * @returns An await URL to the timeline stream
     */
    generateStream(): Promise<string>;
}
