"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Timeline = void 0;
const constants_1 = require("../constants");
const utils_1 = require("../utils");
const asset_1 = require("./asset");
const { timeline } = constants_1.ApiPath;
class Timeline {
    #vhttp;
    timeline;
    streamUrl;
    playerUrl;
    /**
     * Initialize a timeline object
     * @param connection - Connection object. See [[Connection]]
     * @returns Timeline object
     */
    constructor(connection) {
        this.#vhttp = connection.vhttp;
        this.timeline = [];
        this.streamUrl = '';
        this.playerUrl = '';
    }
    getRequestData() {
        const reqData = (0, utils_1.fromCamelToSnake)({
            requestType: 'compile',
            timeline: this.timeline,
        });
        return reqData;
    }
    /**
     * Adds a VideoAsset to the timeline in inline position
     * @param asset - VideoAsset object. Can be created using [[VideoAsset]]
     */
    addInline(asset) {
        if (!(asset instanceof asset_1.VideoAsset)) {
            throw new Error('Asset is not an VideoAsset');
        }
        this.timeline.push(asset.toJSON());
    }
    /**
     * Adds a AudioAsset to the timeline in overlay position
     * @param start - Start time of the overlay w.r.t Base Timline
     * @param asset - AudioAsset, ImageAsset or TextAsset object.
     */
    addOverlay(start, asset) {
        if (!(asset instanceof asset_1.AudioAsset) &&
            !(asset instanceof asset_1.ImageAsset) &&
            !(asset instanceof asset_1.TextAsset)) {
            throw new Error('asset must be of type AudioAsset, ImageAsset or TextAsset');
        }
        this.timeline.push({ ...asset.toJSON(), overlayStart: start });
    }
    /**
     * Generates a Streaming URL for the Timeline object
     * @returns An await URL to the timeline stream
     */
    async generateStream() {
        const reqData = this.getRequestData();
        const streamDataRes = await this.#vhttp.post([timeline], reqData);
        this.streamUrl = streamDataRes.data.stream_url;
        this.playerUrl = streamDataRes.data.player_url;
        return this.streamUrl;
    }
}
exports.Timeline = Timeline;
