"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Connection = exports.connect = exports.waitForJob = exports.playStream = exports.SearchResult = exports.VideodbError = exports.Shot = exports.TranscriptJob = exports.UploadJob = exports.IndexJob = exports.SubtitleBorderStyle = exports.SubtitleAlignment = exports.SceneExtractionType = exports.TextAsset = exports.ImageAsset = exports.AudioAsset = exports.VideoAsset = exports.Image = exports.Audio = exports.Video = exports.Timeline = exports.Collection = void 0;
const connection_1 = require("./core/connection");
Object.defineProperty(exports, "Connection", { enumerable: true, get: function () { return connection_1.Connection; } });
const error_1 = require("./utils/error");
const constants_1 = require("./constants");
/**
 * Entry function for the VideoDB SDK
 * @param apiKey - Your personal API Key. If you don't have one, get one from our {@link https://console.videodb.io | Console}
 * @param baseURL - Server base URL. If you're not sure what this is, skip it. We'll default to our own baseURL
 * @returns A Connection instance that can be used to fetch any collection
 */
function connect(apiKey, baseURL = constants_1.VIDEO_DB_API) {
    apiKey = apiKey || process.env.VIDEO_DB_API_KEY;
    if (!apiKey) {
        throw new error_1.AuthenticationError('No API key provided. Set an API key either as an environment variable (VIDEO_DB_API_KEY) or pass it as an argument.');
    }
    return new connection_1.Connection(baseURL, apiKey);
}
exports.connect = connect;
var collection_1 = require("./core/collection");
Object.defineProperty(exports, "Collection", { enumerable: true, get: function () { return collection_1.Collection; } });
var timeline_1 = require("./core/timeline");
Object.defineProperty(exports, "Timeline", { enumerable: true, get: function () { return timeline_1.Timeline; } });
var video_1 = require("./core/video");
Object.defineProperty(exports, "Video", { enumerable: true, get: function () { return video_1.Video; } });
var audio_1 = require("./core/audio");
Object.defineProperty(exports, "Audio", { enumerable: true, get: function () { return audio_1.Audio; } });
var image_1 = require("./core/image");
Object.defineProperty(exports, "Image", { enumerable: true, get: function () { return image_1.Image; } });
var asset_1 = require("./core/asset");
Object.defineProperty(exports, "VideoAsset", { enumerable: true, get: function () { return asset_1.VideoAsset; } });
Object.defineProperty(exports, "AudioAsset", { enumerable: true, get: function () { return asset_1.AudioAsset; } });
Object.defineProperty(exports, "ImageAsset", { enumerable: true, get: function () { return asset_1.ImageAsset; } });
Object.defineProperty(exports, "TextAsset", { enumerable: true, get: function () { return asset_1.TextAsset; } });
var config_1 = require("./core/config");
Object.defineProperty(exports, "SceneExtractionType", { enumerable: true, get: function () { return config_1.SceneExtractionType; } });
var config_2 = require("./core/config");
Object.defineProperty(exports, "SubtitleAlignment", { enumerable: true, get: function () { return config_2.SubtitleAlignment; } });
Object.defineProperty(exports, "SubtitleBorderStyle", { enumerable: true, get: function () { return config_2.SubtitleBorderStyle; } });
var job_1 = require("./utils/job");
Object.defineProperty(exports, "IndexJob", { enumerable: true, get: function () { return job_1.IndexJob; } });
Object.defineProperty(exports, "UploadJob", { enumerable: true, get: function () { return job_1.UploadJob; } });
Object.defineProperty(exports, "TranscriptJob", { enumerable: true, get: function () { return job_1.TranscriptJob; } });
var shot_1 = require("./core/shot");
Object.defineProperty(exports, "Shot", { enumerable: true, get: function () { return shot_1.Shot; } });
var error_2 = require("./utils/error");
Object.defineProperty(exports, "VideodbError", { enumerable: true, get: function () { return error_2.VideodbError; } });
var searchResult_1 = require("./core/search/searchResult");
Object.defineProperty(exports, "SearchResult", { enumerable: true, get: function () { return searchResult_1.SearchResult; } });
var index_1 = require("./utils/index");
Object.defineProperty(exports, "playStream", { enumerable: true, get: function () { return index_1.playStream; } });
Object.defineProperty(exports, "waitForJob", { enumerable: true, get: function () { return index_1.waitForJob; } });
