"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpClient = void 0;
const constants_1 = require("../constants");
const error_1 = require("../utils/error");
const axios_1 = __importStar(require("axios"));
/**
 * Api initialization to make axios config
 * options available to all child classes
 * internally.
 */
class HttpClient {
    #db;
    #baseURL;
    #apiKey;
    constructor(baseURL, apiKey) {
        this.#db = axios_1.default.create({
            baseURL,
            headers: {
                'x-access-token': apiKey,
            },
            timeout: constants_1.HttpClientDefaultValues.timeout,
        });
        this.#baseURL = baseURL;
        this.#apiKey = apiKey;
    }
    #makeRequest = async (options) => {
        return this.#db
            .request(options)
            .then(successResponse => {
            return this.parseResponse(successResponse.data);
        })
            .catch((error) => {
            if (error instanceof error_1.VideodbError) {
                throw error;
            }
            throw this.#getPlausibleError(error);
        });
    };
    parseResponse = (data) => {
        if (data.success === false) {
            throw new error_1.VideodbError(data.message);
        }
        return data;
    };
    /**
     * Used for getting a human readble and usable error type
     * @param error - The error recieved from the axios request
     * @returns An error class instance from one of the Videodb Error types
     */
    #getPlausibleError = (error) => {
        if (error.response) {
            const errData = error.response.data;
            if (error.status === axios_1.HttpStatusCode.Unauthorized) {
                // For now, the only reason for getting a 401 is an invalid API Key
                return new error_1.AuthenticationError();
            }
            return new error_1.InvalidRequestError(error.response, {
                cause: errData?.message || error.message || 'Unknown cause',
            });
        }
        else if (error.request) {
            return new error_1.VideodbError('Request failed', {
                cause: error.message,
            });
        }
        else {
            return new error_1.VideodbError('Unidentified Error', {
                cause: error,
            });
        }
    };
    get = async (urlSeries, options) => {
        return await this.#makeRequest({
            method: 'GET',
            url: urlSeries.join('/'),
            ...options,
        });
    };
    delete = async (urlSeries, options) => {
        return await this.#makeRequest({
            method: 'DELETE',
            url: urlSeries.join('/') + '/',
            ...options,
        });
    };
    post = async (urlSeries, data, options) => {
        return await this.#makeRequest({
            method: 'POST',
            url: urlSeries.join('/') + '/',
            data,
            headers: new axios_1.AxiosHeaders({
                'Content-Type': 'application/json',
                ...options?.headers,
            }),
            ...options,
        });
    };
    put = async (urlSeries, data, options) => {
        return await this.#makeRequest({
            method: 'PUT',
            url: urlSeries.join('/') + '/',
            data,
            headers: new axios_1.AxiosHeaders({
                'Content-Type': 'application/json',
                ...options?.headers,
            }),
            ...options,
        });
    };
    patch = async (urlSeries, data, options) => {
        return await this.#makeRequest({
            method: 'PATCH',
            url: urlSeries.join('/') + '/',
            data,
            headers: new axios_1.AxiosHeaders({
                'Content-Type': 'application/json',
                ...options?.headers,
            }),
            ...options,
        });
    };
}
exports.HttpClient = HttpClient;
