import { Job } from './job';
import { AudioBase, VideoBase } from '../interfaces/core';
/**
 * TS Interpretation of snake_case to camelCase conversion for better readability
 */
export type SnakeToCamelCase<S extends string> = S extends `${infer T}_${infer U}` ? `${T}${Capitalize<SnakeToCamelCase<U>>}` : S;
/**
 * Return type for function fromSnakeToCamel
 * - T = Type of the input object
 */
export type SnakeKeysToCamelCase<T> = {
    [K in keyof T as SnakeToCamelCase<K & string>]: T[K] extends Array<infer U> ? SnakeKeysToCamelCase<U>[] : T[K] extends object ? SnakeKeysToCamelCase<T[K]> : T[K];
};
/**
 * Converts the provided snake_case object into camelCase
 * @remarks
 * Performs an in-depth conversion. Be careful before passing
 * large objects with a lot of values.
 *
 * @param data - The object that needs to be converted
 * @returns The provided object with all the keys converted into camelCase
 *
 * TODO: Implement this safely at the HttpClient level to avoid rewrites throughout the codebase
 */
export declare const fromSnakeToCamel: <O extends object>(data: O) => SnakeKeysToCamelCase<O>;
export declare const fromCamelToSnake: <O extends object>(data: O) => SnakeKeysToCamelCase<O>;
export declare const playStream: (url: string) => string;
export declare const waitForJob: (job: Job<any, any>) => Promise<any>;
export declare const isMediaAudio: (media: AudioBase | VideoBase) => media is AudioBase;
