"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isMediaAudio = exports.waitForJob = exports.playStream = exports.fromCamelToSnake = exports.fromSnakeToCamel = void 0;
const constants_1 = require("../constants");
const lodash_1 = __importDefault(require("lodash"));
/**
 * Converts the provided snake_case object into camelCase
 * @remarks
 * Performs an in-depth conversion. Be careful before passing
 * large objects with a lot of values.
 *
 * @param data - The object that needs to be converted
 * @returns The provided object with all the keys converted into camelCase
 *
 * TODO: Implement this safely at the HttpClient level to avoid rewrites throughout the codebase
 */
const fromSnakeToCamel = (data) => {
    const finalData = (0, lodash_1.default)(data)
        .mapKeys((__, k) => lodash_1.default.camelCase(k))
        .mapValues(v => {
        if (lodash_1.default.isArray(v)) {
            return v.map(item => (0, exports.fromSnakeToCamel)(item));
        }
        else if (lodash_1.default.isObject(v)) {
            return (0, exports.fromSnakeToCamel)(v);
        }
        else {
            return v;
        }
    })
        .value();
    return finalData;
};
exports.fromSnakeToCamel = fromSnakeToCamel;
const fromCamelToSnake = (data) => {
    const finalData = (0, lodash_1.default)(data)
        .mapKeys((__, k) => lodash_1.default.snakeCase(k))
        .mapValues(v => {
        if (lodash_1.default.isArray(v)) {
            const array = v.map(item => {
                if (lodash_1.default.isObject(item))
                    return (0, exports.fromCamelToSnake)(item);
                // @ts-ignore
                return item;
            });
            // @ts-ignore
            return array;
        }
        else if (lodash_1.default.isObject(v)) {
            return (0, exports.fromCamelToSnake)(v);
        }
        else {
            return v;
        }
    })
        .value();
    return finalData;
};
exports.fromCamelToSnake = fromCamelToSnake;
const playStream = (url) => `${constants_1.PLAYER_URL}?url=${url}`;
exports.playStream = playStream;
const waitForJob = async (job) => {
    return new Promise((resolve, reject) => {
        job.on('success', async (data) => {
            resolve(data);
        });
        job.on('error', async (err) => {
            reject(err);
        });
        job
            .start()
            .then(() => {
            console.log('Job started');
        })
            .catch(err => {
            console.log('Job Failed');
            reject(err);
        });
    });
};
exports.waitForJob = waitForJob;
const isMediaAudio = (media) => {
    return media.id.startsWith('a-');
};
exports.isMediaAudio = isMediaAudio;
