"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.uploadToServer = exports.getUploadUrl = void 0;
const constants_1 = require("../constants");
const error_1 = require("../utils/error");
const job_1 = require("../utils/job");
const form_data_1 = __importDefault(require("form-data"));
const fs_1 = require("fs");
const { upload_url, collection, upload } = constants_1.ApiPath;
/**
 * Get an upload URL. Use this to upload your video to
 * VideoDB's storage.
 * @returns A URL that can be used to upload a video.
 * The uploaded video will be available on the same URL
 * @see This won't save directly save your
 * video to the database. Call uploadVideoByUrl once
 * with the returned URL for the video to be saved.
 */
const getUploadUrl = async (http, collectionId) => {
    const res = await http.get([
        collection,
        collectionId,
        upload_url,
    ]);
    const { data } = res;
    return data.upload_url;
};
exports.getUploadUrl = getUploadUrl;
/**
 * @param filePath - absolute path to a file
 * @param url - a url to a pre-uploaded file
 * @param callbackUrl-  A url that will be called once upload is finished
 * @param name - Name of the file
 * @param description - Description of the file
 */
const uploadToServer = async (http, collectionId, data) => {
    let urlToUpload = '';
    if ('filePath' in data) {
        const uploadUrl = await (0, exports.getUploadUrl)(http, collectionId);
        try {
            const fileStream = (0, fs_1.createReadStream)(data.filePath);
            const formData = new form_data_1.default();
            formData.append('file', fileStream);
            await http.post([uploadUrl], formData, {
                headers: formData.getHeaders(),
            });
        }
        catch (err) {
            throw new error_1.VideodbError('Upload failed, reason: ', err);
        }
        urlToUpload = uploadUrl;
    }
    else {
        urlToUpload = data.url;
    }
    const finalData = {
        url: urlToUpload,
        name: data.name,
        description: data.description,
        callback_url: data.callbackUrl,
        media_type: data.mediaType,
    };
    if (finalData.callback_url) {
        await http.post([collection, collectionId, upload], finalData);
    }
    else {
        return new job_1.UploadJob(finalData, collectionId, http);
    }
};
exports.uploadToServer = uploadToServer;
